@@ -7,7 +7,7 @@ from scalr_manage.library.install.test.util import BaseInstallTestCase
 
 class CliTestCase(BaseInstallTestCase):
     def test_error_noconfig(self):
-        argv = ["document"]
+        argv = ["scalr-manage", "document"]
         ret = cli._main(argv, self.ui, self.tokgen)
         self.assertEqual(-2, ret)
 
@@ -20,8 +20,10 @@ class InstallErrorTestCase(BaseInstallTestCase):
         log_file = os.path.join(self.work_dir, "log.log")
 
         # This uses its own parser and doesn't default to our solo.json path!
-        argv = ["-c", self.solo_json_path, "install", "-l", log_file]
+        argv = ["scalr-manage", "-c", self.solo_json_path, "install", "-l", log_file]
         ret = cli._main(argv, self.ui, self.tokgen)
 
         self.assertEqual(1, ret)
         self.assertTrue(any(log_file in msg for msg in self.output.outputs), "Path to log file wasn't printed!")
+        for arg in argv:
+            self.assertTrue(any(arg in msg for msg in self.output.outputs), "Arg {0} wasn't printed".format(arg))
